BuildProof class

Prova verificável de uma execução de build.

Constructors

BuildProof({required String graphHash, required String deltaHash, required List<String> affectedNodes, required int cacheHits, required List<String> rebuiltNodes, required String finalArtifactHash})

Properties

affectedNodes List<String>
final
cacheHits int
final
deltaHash String
final
finalArtifactHash String
final
graphHash String
final
hashCode int
The hash code for this object.
no setterinherited
rebuiltNodes List<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited