BuildProofIR class

Unidade final de verdade do build system. Contém o grafo resolvido e as provas de integridade.

Constructors

BuildProofIR({required String componentName, required String buildProofHash, required Map<String, String> contentHashes, required Map<String, List<String>> dependencyIndex, required BuildProof proof})

Properties

buildProofHash String
final
componentName String
final
contentHashes Map<String, String>
final
dependencyIndex Map<String, List<String>>
final
hashCode int
The hash code for this object.
no setterinherited
proof BuildProof
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited