ComponentRegistry class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
availableComponents
→ List<
String> -
no setter
Static Methods
-
getComponent(
String name) → ComponentConfig? -
getComponentByPath(
String path) → ComponentConfig? -
loadFromDisk(
{String? customPath}) → Future< void> - Carrega o registro de componentes a partir do arquivo JSON.