PipelineContext class

Constructors

PipelineContext({required String componentName, String? variant, bool overwrite = false, required String projectRoot})

Properties

cacheHits int
getter/setter pair
componentName String
final
config ↔ ComponentConfig
getter/setter pair
fileManifest Map<String, String>
final
hashCode int
The hash code for this object.
no setterinherited
ir ComponentIR
getter/setter pair
lastBuildState Map<String, dynamic>?
getter/setter pair
overwrite bool
final
plan BuildPlan
getter/setter pair
projectName String
getter/setter pair
projectRoot String
final
proof BuildProof
getter/setter pair
rebuiltNodes List<String>
final
resolvedFiles List<ComponentFile>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
variant String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited