TemplateBinding class

Constructors

TemplateBinding({required String templatePath, required String templateName, required String fileName, required String templateHash, required String contentHash})

Properties

contentHash String
final
fileName String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
templateHash String
final
templateName String
final
templatePath String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited