BuildPlan class

BuildPlan represents the execution strategy for the incremental build engine. It determines which components need to be rendered from scratch and which ones can be safely reused from the previous build state.

Constructors

BuildPlan({required List<String> nodesToRebuild, required List<String> nodesFromCache, required Map<String, String> invalidationReasons, required String planHash})
Creates a new BuildPlan with the specified rebuild and cache nodes.

Properties

hashCode int
The hash code for this object.
no setterinherited
invalidationReasons Map<String, String>
Detailed reasons why specific components were invalidated.
final
isFullRebuild bool
no setter
isIncremental bool
no setter
isNoOp bool
no setter
nodesFromCache List<String>
List of component names that will be recovered from cache.
final
nodesToRebuild List<String>
List of component names that need to be rebuilt.
final
planHash String
Unique identifier of this build strategy.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited