ComponentIR class
Representação Intermediária (IR) imutável do componente. Garantia de determinismo: Mesma configuração -> Mesmo Hash.
Constructors
-
ComponentIR({required String componentName, required Map<
String, TemplateBinding> resolvedFiles, required List<String> dependencies, required String irHash}) -
ComponentIR.create(String name, List<
ComponentFile> files, String templatePath, {List<String> dependencies = const [], Map<String, String> templateHashes = const {}}) -
factory
Properties
- componentName → String
-
final
-
dependencies
→ List<
String> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- irHash → String
-
final
-
resolvedFiles
→ Map<
String, TemplateBinding> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited